@@ -6,12 +6,14 @@ from functools import wraps
 from django.contrib.sites.models import Site
 from django.core.urlresolvers import reverse
 from django.http import HttpResponse, HttpResponseNotAllowed, HttpResponseBadRequest
+from django.shortcuts import get_object_or_404
 from django.views.decorators.http import require_POST
 from django.views.decorators.csrf import csrf_exempt
-from ebaysuds import EbaySuds, WSDL_URL
+from ebaysuds import EbaySuds
 from suds.plugin import PluginContainer
 
 from . import NOTIFICATION_PAYLOADS
+from .models import UserToken
 from .notifications import NotificationHandler
 from .signals import ebay_platform_notification
 
@@ -20,16 +22,16 @@ logging.basicConfig()
 log = logging.getLogger(__name__)
 
 
-def get_notification_url():
+def get_notification_url(usernasme=None):
     current_site = Site.objects.get_current()
     if current_site.domain == 'example.com':
         warnings.warn("You have not configured your Django sites framework, current site points to example.com")
-    return 'http://%s%s' % (current_site.domain, reverse('ebaysync:notification'))
+    return 'http://%s%s' % (current_site.domain, reverse('ebaysync:notification', kwargs={'username': username}))
 
 
 @require_POST
 @csrf_exempt
-def notification(request):
+def notification(request, username=None):
     try:
         action = request.META['HTTP_SOAPACTION']
     except KeyError:
@@ -53,7 +55,14 @@ def notification(request):
         log.error(msg)
         return HttpResponseBadRequest(msg)
 
-    handler = NotificationHandler(WSDL_URL)
+            user = UserToken.objects.get(ebay_username=for_user)
+
+    nh_kwargs = {}
+    if username is not None:
+        user = get_object_or_404(UserToken, ebay_username=username)
+        nh_kwargs['token'] = user.token
+        nh_kwargs['sandbox'] = user.is_sandbox
+    handler = NotificationHandler(**nh_kwargs)
     payload = handler.decode(payload_type, request.body)
 
     # fire django signal
